SystemIdleLinux class abstract

An implementation of the system_idle plugin for Linux (Wayland and X11).

Constructors

SystemIdleLinux()

Properties

hashCode int
The hash code for this object.
no setterinherited
isSupported bool
Whether idle detection is supported on this device.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Releases any resources associated with this object.
inherited
getIdleDuration() Future<Duration?>
Returns how long the user has been idle for already.
inherited
initialize() Future<void>
Initializes the plugin.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onIdleChanged({required Duration idleDuration}) Stream<bool>
Returns a stream that emits when the user becomes idle (true) or active (false).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forWindowManager() → SystemIdlePlatformInterface
Determines which Window manager to work with. Only Wayland and X11 are supported.